GodexIP class

Constructors

GodexIP(String _addr)

Properties

hashCode int
The hash code for this object.
no setterinherited
onError ↔ void Function(String)
getter/setter pair
onReceive ↔ void Function(String)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginLabel() Future<bool>
calibrate() Future<bool>
close() Future<void>
drawImage(Image image, {int startX = 0, int startY = 0}) Future<bool>
endLabel() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() Future<bool>
sendcommand(String msg) Future<bool>
setup(PrintingMode mode, PaperType paper, int heightMm, int widthMm, int gapMm, {int? blackness, int? speed, int? topMm}) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pixelBrightness(int rgbPixel) int
scanNetwork(int timeoutms) Future<List<InternetAddress>>